@@ -145,7 +145,6 @@ def get_billboard_list(stock_list=None, start_date=None, end_date=None):
     return MtDataClient.instance().get_billboard_list(**locals())
 
 
-
 @assert_auth
 def get_locked_shares(stock_list=None, start_date=None, end_date=None, forward_count=None):
     """
@@ -389,7 +388,7 @@ def get_dominant_future(underlying_symbol, date=None):
     :return 主力合约对应的期货合约
     """
     dt = to_date_str(date)
-    return MtDataClient.instance().get_dominant_future(underlying_symbol=underlying_symbol, dt=dt)
+    return MtDataClient.instance().get_dominant_future(underlying_symbol=underlying_symbol, date=date)
 
 
 # @assert_auth
